@@ -12,10 +12,17 @@
          END DO
       END DO
 
-      CALL SWISET('WINDOW_HEIGHT', 300)
-      CALL SWISET('WINDOW_WIDTH', 300)
+      CALL UILSET('LCELLX',.TRUE.)
+      CALL UILSET('LCELLY',.TRUE.)
 
-      CALL GROPN(1)
+      CALL SWISET('WINDOW_HEIGHT', 600)
+      CALL SWISET('WINDOW_WIDTH', 600)
+
+      WRITE(*,*) ' WORKSTATION ID (I) ? ;'
+      CALL SGPWSN
+      READ(*,*) IWS
+
+      CALL GROPN(IWS)
       CALL GRFRM
       CALL GRSWND(-1., 1., -1., 1.)
       CALL GRSVPT(.1, .9, .1, .9)
