@@ -1,18 +1,18 @@
 *-----------------------------------------------------------------------
 *     BASIC TEXT PRIMITIVE ON VC
 *-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SZTXWV(VX,VY,CHARS)
 
       CHARACTER CHARS*(*)
 
-      PARAMETER (NCHAR=256,LEN=6000)
+      PARAMETER (NCHAR=2048,LEN=6000)
       PARAMETER (WUNIT=24,ZUNIT=24)
 
       INTEGER   IPOSX(NCHAR)
       REAL      WX1(NCHAR),WX2(NCHAR)
-      CHARACTER CKX(LEN)*1,CKY(LEN)*1,CBUF*80,COBJ*80
+      CHARACTER CKX(LEN)*1,CKY(LEN)*1
 
       COMMON    /SZBTX1/ QSIZE,CT,ST,ICENTZ
       COMMON    /SZBTX2/ LCNTL,JSUP,JSUB,JRST,SMALL,SHIFT
@@ -23,7 +23,7 @@
       INTEGER   ISUP,ISUB,IRST
       CHARACTER CSGI*1,CSUP*1,CSUB*1,CRST*1
       INTEGER   IMODE, IDEST
-      CHARACTER CHARZ*(NCHAR)
+      CHARACTER CHARZ*(NCHAR),CHARX*(NCHAR)
 
       EXTERNAL  LENC,ISGC
 
@@ -31,7 +31,6 @@
 
       DATA      NCNTZ/0/
 
-
 *      / START: CODE FOR USING SYSTEN FONTS /
 *      / PROCCESS IF NOT MARKER /
       CALL SWLGET("SYSFONT", SYSFONT)
@@ -57,7 +56,6 @@
         CALL SWFTFC(FONTNAME)
       END IF
 
-
       IDX=ISGC(CHARS(1:1))
       CALL SGLGET('MARKFONT',MARKFONT)
 
@@ -95,9 +93,42 @@
         CALL SZQFNW(WX1,WX2)
         NCNTZ=NCNT
       END IF
+*     /REMOVE DCL EXT CHARACTER MARKER */
+      NCZ=LENC(CHARS)
+      J=0
+      DO 999 I=1,NCZ
+        IDX0=ISGC(CHARS(I:I))
+        IF(IDX0.EQ.92)THEN
+           IMODE=1
+        END IF
+        IF(IMODE.EQ.0 .OR. IMODE.EQ.4)THEN
+          J=J+1
+          CHARX(J:J)=CHARS(I:I)
+          IMODE=0
+        END IF
+        IF(IMODE.EQ.3)THEN
+          IF(IDX0.EQ.120)THEN
+            IMODE=2
+          ELSE
+            J=J+1
+            CHARX(J:J)=CSGI(92)
+            J=J+1
+            CHARX(J:J)=CHARS(I:I)
+            IMODE=0
+          END IF
+        END IF
+        IF(IMODE.EQ.1 .OR. IMODE.EQ.2)THEN
+          IMODE=IMODE+2
+        END IF
+  999 CONTINUE
+
+      DO 998 I=J+1,2048
+        CHARX(I:I)=' '
+  998 CONTINUE
+      CHARX=TRIM(CHARX)
 
 *     / CONVERT NEW TYPE MARKUPS TO OLD ONE /
-      NCZ=LENC(CHARS)
+      NCZ=LENC(CHARX)
       DO 1 N=1,NCHAR
         CHARZ=' '
     1 CONTINUE
@@ -112,7 +143,7 @@
       IMODE=0
       LMARK=.TRUE.
       DO 3 N=1,NCZ
-        IDX0=ISGC(CHARS(N:N))
+        IDX0=ISGC(CHARX(N:N))
         IF(IMODE.EQ.1)THEN
           IF (IDX0.EQ.94)THEN
             CHARZ(IDEST:IDEST)=CSUP
@@ -140,7 +171,7 @@
             IMODE=2
           ELSE
             IMODE=0
-            CHARZ(IDEST:IDEST)=CHARS(N:N)
+            CHARZ(IDEST:IDEST)=CHARX(N:N)
             IDEST=IDEST+1
             IF(LMARK) THEN
               CHARZ(IDEST:IDEST)=CRST
@@ -150,7 +181,7 @@
             END IF
           END IF
         ELSE IF (IMODE.EQ.2) THEN
-          IF(ISGC(CHARS(N:N)).EQ.125)THEN
+          IF(ISGC(CHARX(N:N)).EQ.125)THEN
             IMODE=0
             IF(LMARK)THEN
               CHARZ(IDEST:IDEST)=CRST
@@ -159,14 +190,14 @@
               LMARK=.TRUE.
             END IF
           ELSE
-            CHARZ(IDEST:IDEST)=CHARS(N:N)
+            CHARZ(IDEST:IDEST)=CHARX(N:N)
             IDEST=IDEST+1
           END IF
-*       92:\ 94:^ 95:_ 111:o 117:u 123:{ 125:}
+*       92:\ 94:^ 95:_ 111:o 117:u 120:u 123:{ 125:}
         ELSE IF (IDX0.EQ.92) THEN
             IMODE=1
         ELSE
-          CHARZ(IDEST:IDEST)=CHARS(N:N)
+          CHARZ(IDEST:IDEST)=CHARX(N:N)
           IDEST=IDEST+1
         END IF
     3 CONTINUE
@@ -181,34 +212,11 @@
       IF (IDEST.LE.NCZ)THEN
         NCZ=IDEST-1
       END IF
+*  / END CONVERT MARKUPS /
+
 
       CALL SZQTXW(CHARZ,NC,WXCH,WYCH)
 
-*     / WRITE INFORMATION FOR PS DRIVER /
-
-      CALL STFWTR(VX,VY,WX,WY)
-
-      CBUF=' '
-      NP=0
-      DO 5 N=1,NCZ
-        ICZ=ISGC(CHARZ(N:N))
-        NP=NP+1
-        IF (32.LE.ICZ .AND. ICZ.LE.127 .AND. ICZ.NE.37) THEN
-          CBUF(NP:NP)=CHARZ(N:N)
-        ELSE
-          WRITE(CBUF(NP:NP+3),'(A,I3.3)') '%',ICZ
-          NP=NP+3
-        END IF
-    5 CONTINUE
-      WRITE(COBJ,'(2I8)') INT(WX),INT(WY)
-      CALL CDBLK(COBJ)
-      IF (LENC(CBUF) .EQ. 80) THEN
-        CALL MSGDMP('E','SZTXWV',
-     +  'STRING LENGTH TOO LONG. CONSIDER USING SYSTEM FONT.')
-      END IF
-      WRITE(COBJ(LENC(COBJ)+1:80),'(A)') ' "'//CBUF(1:NP)//'"'
-      CALL SWOOPN('SZTXZ',COBJ)
-
 *     / CALCULATE OFFSET VALUES /
 
       OFFX=-0.5*WXCH*WUNIT*(ICENTZ+1)
@@ -228,7 +236,6 @@
       DO 20 K=1,NCZ
 
 *       / CHARACTER CONVERSION /
-
         IDX=ISGC(CHARZ(K:K))+1
         IPS=IPOSX(IDX)+1
 
